src/eric7/DocumentationTools/QtHelpGenerator.py

branch
eric7
changeset 10423
299802979277
parent 9653
e67609152c5e
child 10439
21c28b0f9e41
--- a/src/eric7/DocumentationTools/QtHelpGenerator.py	Tue Dec 19 11:04:03 2023 +0100
+++ b/src/eric7/DocumentationTools/QtHelpGenerator.py	Tue Dec 19 19:57:08 2023 +0100
@@ -75,16 +75,24 @@
         """
         Constructor
 
-        @param htmlDir directory containing the HTML files (string)
-        @param outputDir output directory for the files (string)
-        @param namespace namespace to be used (string)
-        @param virtualFolder virtual folder to be used (string)
-        @param filterName name of the custom filter (string)
+        @param htmlDir directory containing the HTML files
+        @type str
+        @param outputDir output directory for the files
+        @type str
+        @param namespace namespace to be used
+        @type str
+        @param virtualFolder virtual folder to be used
+        @type str
+        @param filterName name of the custom filter
+        @type str
         @param filterAttributes ':' separated list of filter attributes
-            (string)
-        @param title title to be used for the generated help (string)
+           
+        @type str
+        @param title title to be used for the generated help
+        @type str
         @param createCollection flag indicating the generation of the
-            collection files (boolean)
+            collection files
+        @type bool
         """
         self.htmlDir = htmlDir
         self.outputDir = outputDir
@@ -104,12 +112,15 @@
         """
         Public method to remember a documentation file.
 
-        @param file The filename to be remembered. (string)
-        @param moduleDocument The ModuleDocument object containing the
+        @param file The filename to be remembered.
+        @type str
+        @param moduleDocument module documentation object containing the
             information for the file.
-        @param basename The basename of the file hierarchy to be documented.
-            The basename is stripped off the filename if it starts with
-            the basename.
+        @type ModuleDocument
+        @param basename base name of the file hierarchy to be documented.
+            The base name is stripped off the filename if it starts with
+            the base name.
+        @type str
         """
         self.remembered = True
         if basename:
@@ -169,9 +180,12 @@
         """
         Private method to generate the sections part.
 
-        @param package name of the package to process (string)
-        @param level indentation level (integer)
-        @return sections part (string)
+        @param package name of the package to process
+        @type str
+        @param level indentation level
+        @type int
+        @return sections part
+        @rtype str
         """
         indent = level * "  "
         indent1 = indent + "  "
@@ -194,9 +208,12 @@
         """
         Private method to convert the newline characters.
 
-        @param txt text to be converted (string)
-        @param newline newline character to be used (string)
-        @return converted text (string)
+        @param txt text to be converted
+        @type str
+        @param newline newline character to be used
+        @type str
+        @return converted text
+        @rtype str
         """
         # step 1: normalize eol to '\n'
         txt = txt.replace("\r\n", "\n").replace("\r", "\n")
@@ -213,10 +230,12 @@
         """
         Public method to generate all index files.
 
-        @param basename The basename of the file hierarchy to be documented.
-            The basename is stripped off the filename if it starts with
-            the basename.
-        @param newline newline character to be used (string)
+        @param basename base name of the file hierarchy to be documented.
+            The base name is stripped off the filename if it starts with
+            the base name.
+        @type str
+        @param newline newline character to be used
+        @type str
         """
         if not self.remembered:
             sys.stderr.write("No QtHelp to generate.\n")

eric ide

mercurial